# Summary

[Copyright](./copyright.md)
[Dedication](./dedication.md)
[Preface](./preface.md)

- [API Reference](./api/index.md)

  - [Initialization](./api/init.md)

  - [Messages](./api/msg.md)

  - [Sockets](./api/sock.md)

  - [Contexts](./api/ctx.md)

  - [Pipes](./api/pipe.md)

  - [Memory](./api/memory.md)

  - [Time](./api/time.md)

  - [URLs](./api/url.md)

  - [Asynchronous I/O](./api/aio.md)

  - [Synchronization](./api/synch.md)

  - [Threads](./api/thread.md)

  - [Logging](./api/logging.md)

  - [Statistics](./api/stats.md)

  - [Errors](./api/errors.md)

  - [Streams](./api/stream.md)

  - [HTTP](./api/http.md)

  - [Miscellaneous](./api/misc.md)

  - [ID Map](./api/id_map.md)

  - [Arguments Parser](./api/args.md)

- [Protocols](./proto/index.md)

  - [BUS Protocol](./proto/bus.md)
  - [PAIR Protocol](./proto/pair.md)
  - [PUB Protocol](./proto/pub.md)
  - [PULL Protocol](./proto/pull.md)
  - [PUSH Protocol](./proto/push.md)
  - [REP Protocol](./proto/rep.md)
  - [REQ Protocol](./proto/req.md)
  - [RESPONDENT Protocol](./proto/respondent.md)
  - [SUB Protocol](./proto/sub.md)
  - [SURVEYOR Protocol](./proto/surveyor.md)

- [Transports](./tran/index.md)

  - [Intra-Process Transport](./tran/inproc.md)
  - [Inter-Process Transport](./tran/ipc.md)
  - [BSD Socket (Experimental)](./tran/socket.md)
  - [UDP Transport (Experimental)](./tran/udp.md)

- [Migration Guides](./migrate/index.md)

  - [Migrating from NNG 1.x](./migrate/nng1.md)
  - [Migrating from libnanomsg](./migrate/nanomsg.md)

[Index](./indexing.md)
